@@ -1,7 +1,7 @@
 #ifndef LIBXL_C_H
 #define LIBXL_C_H
 
-#define LIBXL_VERSION 0x03080000
+#define LIBXL_VERSION 0x03080200
 
 #ifdef _UNICODE
 
@@ -20,6 +20,7 @@
     #define xlBookSaveUsingTempFile xlBookSaveUsingTempFileW
     #define xlBookLoadPartially xlBookLoadPartiallyW
     #define xlBookLoadPartiallyUsingTempFile xlBookLoadPartiallyUsingTempFileW
+    #define xlBookLoadWithoutEmptyCells xlBookLoadWithoutEmptyCellsW
     #define xlBookLoadRaw xlBookLoadRawW
     #define xlBookLoadRawPartially xlBookLoadRawPartiallyW
     #define xlBookSaveRaw xlBookSaveRawW
@@ -208,7 +209,7 @@
     #define xlSheetAddDataValidationEx xlSheetAddDataValidationExW
     #define xlSheetAddDataValidationDouble xlSheetAddDataValidationDoubleW
     #define xlSheetAddDataValidationDoubleEx xlSheetAddDataValidationDoubleExW
-    #define xlSheetRemoveDataValidations removeDataValidationsW
+    #define xlSheetRemoveDataValidations xlSheetRemoveDataValidationsW
 
     #define xlFontSize xlFontSizeW
     #define xlFontSetSize xlFontSetSizeW
@@ -316,6 +317,7 @@
     #define xlBookSaveUsingTempFile xlBookSaveUsingTempFileA
     #define xlBookLoadPartially xlBookLoadPartiallyA
     #define xlBookLoadPartiallyUsingTempFile xlBookLoadPartiallyUsingTempFileA
+    #define xlBookLoadWithoutEmptyCells xlBookLoadWithoutEmptyCellsA
     #define xlBookLoadRaw xlBookLoadRawA
     #define xlBookLoadRawPartially xlBookLoadRawPartiallyA
     #define xlBookSaveRaw xlBookSaveRawA
@@ -504,7 +506,7 @@
     #define xlSheetAddDataValidationEx xlSheetAddDataValidationExA
     #define xlSheetAddDataValidationDouble xlSheetAddDataValidationDoubleA
     #define xlSheetAddDataValidationDoubleEx xlSheetAddDataValidationDoubleExA
-    #define xlSheetRemoveDataValidations removeDataValidationsA
+    #define xlSheetRemoveDataValidations xlSheetRemoveDataValidationsA
 
     #define xlFontSize xlFontSizeA
     #define xlFontSetSize xlFontSetSizeA
